#[non_exhaustive]pub enum OutputFormat {
Pretty,
Json,
}Expand description
The rendering format for an error reported to a consumer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pretty
The human-readable Error: {display} line.
Json
The RFC 9457 application/problem+json envelope.
Implementations
Sourceimpl OutputFormat
impl OutputFormat
Sourcepub fn select(explicit: Option<&str>, is_terminal: bool) -> Self
pub fn select(explicit: Option<&str>, is_terminal: bool) -> Self
Selects the output format for a consumer.
JSON when --format=json is given explicitly, or when no format is
given and the error stream is not a terminal. Pretty when
--format=pretty is given, or when no format is given and the error
stream is a terminal. An unrecognized explicit value falls back to
the TTY heuristic.
Arguments
explicit- The value of an explicit--formatflag, if any.is_terminal- Whether the error stream is a TTY.
Returns
The selected OutputFormat.